@@ -24,7 +24,7 @@
  * @author Samuel Mimram
  */
 
-/* $Id: shout_stubs.c 2665 2006-07-26 16:00:46Z smimram $ */
+/* $Id: shout_stubs.c 4669 2007-10-17 16:27:50Z metamorph68 $ */
 
 #define CAML_NAME_SPACE
 #include <caml/alloc.h>
@@ -86,13 +86,14 @@ CAMLprim value ocaml_shout_version(value unit)
 
 CAMLprim value ocaml_shout_new(value unit)
 {
-  value block;
+  CAMLparam0();
+  CAMLlocal1(block);
   shout_t *s = shout_new();
   if (s == NULL)
     caml_raise_constant(*caml_named_value("shout_exn_malloc"));
   block = caml_alloc_custom(&shout_ops, sizeof(shout_t*), 0, 1);
   Shout_val(block) = s;
-  return block;
+  CAMLreturn(block);
 }
 
 CAMLprim value ocaml_shout_get_error(value block)
@@ -484,6 +485,7 @@ CAMLprim value ocaml_shout_delay(value block)
 CAMLprim value ocaml_shout_set_metadata(value block, value data)
 {
   CAMLparam2(block, data);
+  CAMLlocal1(c);
   shout_t *s = Shout_val(block);
   shout_metadata_t *metadata = shout_metadata_new();
   int i, ret;
@@ -491,7 +493,6 @@ CAMLprim value ocaml_shout_set_metadata(value block, value data)
 
   for (i=0; i<Wosize_val(data); i++)
     {
-      CAMLlocal1(c);
       c = Field(data, i);
       name = String_val(Field(c, 0));
       val = String_val(Field(c, 1));
